@@ -35,7 +35,7 @@ check.estdata <- function(esttype, pop_dsn=NULL, pop_fmt=NULL, totals=TRUE,
   ## Set global variables
   rawfolder <- NULL
   isdb <- FALSE
-
+  whereqry <- NULL
 
   #############################################################################
   ## Check esttype
@@ -84,7 +84,11 @@ check.estdata <- function(esttype, pop_dsn=NULL, pop_fmt=NULL, totals=TRUE,
   ###########################################################################
   ## Apply pcfilter (plot and cond filters) to pltcondf table
   ###########################################################################
+  if (!is.null(pcfilter)) {
+    whereqry <- paste0("\nWHERE ", RtoSQL(pcfilter))
+  }
   pltcondnmlst <- names(pltcondf)
+  
   pltcondf <- datFilter(x = pltcondf, 
                         xfilter = pcfilter, 
 						title.filter = "plt filter?",
@@ -138,7 +142,14 @@ check.estdata <- function(esttype, pop_dsn=NULL, pop_fmt=NULL, totals=TRUE,
       }
     }
   }
-
+  if (!is.null(landarea.filter)) {
+    if (!is.null(whereqry)) {
+      whereqry <- paste0(whereqry, " AND ", RtoSQL(landarea.filter))
+	} else {
+	  whereqry <- paste0("\nWHERE ", RtoSQL(landarea.filter))
+    }	  
+  }
+  
   ###################################################################################
   ## Apply landarea filters
   ###################################################################################
@@ -274,7 +285,7 @@ check.estdata <- function(esttype, pop_dsn=NULL, pop_fmt=NULL, totals=TRUE,
  	landarea=landarea, rawdata=rawdata, rawonly=rawonly, savedata=savedata,
 	outfolder=outfolder, overwrite_layer=overwrite_layer, append_layer=append_layer,
 	rawfolder=rawfolder, raw_fmt=raw_fmt, raw_dsn=raw_dsn, pop_fmt=pop_fmt, 
-	pop_dsn=pop_dsn)
+	pop_dsn=pop_dsn, whereqry=whereqry)
 
 
   if (esttype %in% c("TREE", "RATIO", "SEED")) {
@@ -298,11 +309,11 @@ check.estdata <- function(esttype, pop_dsn=NULL, pop_fmt=NULL, totals=TRUE,
     if (estseed != "only") {
       treex <- pcheck.table(treex, conn = conn, stopifnull = TRUE, 
                        stopifinvalid = TRUE, checkonly = TRUE)				
-      if (is.data.frame(treex)) {
+       if (is.data.frame(treex)) {
         ## Check the values of tuniqueid in treex are all in cuniqueid in pltcondf
         treef <- check.matchval(treex, pltcondf, tuniqueid, cuniqueid, 
                       tab1txt="tree", tab2txt="cond", subsetrows=TRUE)
-        returnlst$treef <- setDT(treef)
+        returnlst$treef <- data.table(treef)
 		treenames <- names(treef)
       } else {
 	    returnlst$treef <- treex
@@ -323,7 +334,7 @@ check.estdata <- function(esttype, pop_dsn=NULL, pop_fmt=NULL, totals=TRUE,
         ## Check the values of tuniqueid in seedx are all in cuniqueid in pltcondf
         seedf <- check.matchval(seedx, pltcondf, tuniqueid, cuniqueid, 
                        tab1txt="seed", tab2txt="cond", subsetrows=TRUE)
-        returnlst$seedf <- setDT(seedf)
+        returnlst$seedf <- data.table(seedf)
 		seednames <- names(seedf)
       } else {
 	    returnlst$seedf <- seedx
