@@ -39,12 +39,15 @@
 #' @param adjcond Logical. If TRUE, csumvar condition variables are adjusted
 #' for nonsampled conditions by plot.
 #' @param NAto0 Logical. If TRUE, convert NA values to 0.
+#' @param cround Number. The number of digits to round to. If NULL, default=5.
 #' @param returnDT Logical. If TRUE, returns data.table object(s). If FALSE,
 #' returns data.frame object(s).
 #' @param savedata Logical. If TRUE, saves data to outfolder.
 #' @param savedata_opts List. See help(savedata_options()) for a list
 #' of options. Only used when savedata = TRUE. If out_layer = NULL,
-#' default = 'condsum'. 
+#' default = 'condsum'.
+#' @param dbconn Open database connection.
+#' @param dbconnopen Logical. If TRUE, keep database connection open. 
 #' @param gui Logical. If gui, user is prompted for parameters.
 #' 
 #' @return A list of the following items: \item{condsum}{ Data frame.
@@ -82,9 +85,12 @@ datSumCond <- function(cond = NULL,
                        getadjplot = FALSE,
                        adjcond = FALSE, 
                        NAto0 = FALSE, 
+                       cround = 5, 
                        returnDT = TRUE,
                        savedata = FALSE, 
                        savedata_opts = NULL,
+                          dbconn = NULL,
+                          dbconnopen = FALSE,
                        gui = FALSE){
   
   #####################################################################################
@@ -314,6 +320,11 @@ datSumCond <- function(cond = NULL,
     adjcond <- TRUE
   }
 
+  ## CHECK tround
+  if (is.null(cround) | !is.numeric(cround)) {
+    warning("cround is invalid.. rounding to 5 digits")
+    tround <- 5
+  }
 
   ## Check savedata 
   savedata <- pcheck.logical(savedata, varnm="savedata", title="Save data table?", 
@@ -324,7 +335,8 @@ datSumCond <- function(cond = NULL,
     outlst <- pcheck.output(outfolder=outfolder, out_dsn=out_dsn, 
         out_fmt=out_fmt, outfn.pre=outfn.pre, outfn.date=outfn.date, 
         overwrite_dsn=overwrite_dsn, overwrite_layer=overwrite_layer,
-        add_layer=add_layer, append_layer=append_layer, gui=gui)
+        add_layer=add_layer, append_layer=append_layer, out_conn=dbconn, 
+         dbconnopen=TRUE, gui=gui)
     outfolder <- outlst$outfolder
     out_dsn <- outlst$out_dsn
     out_fmt <- outlst$out_fmt
@@ -335,6 +347,7 @@ datSumCond <- function(cond = NULL,
     if (is.null(out_layer)) {
       out_layer <- "condsum"
     }
+    out_conn = outlst$out_conn
   }
   
 
@@ -457,7 +470,7 @@ datSumCond <- function(cond = NULL,
                                   append_layer = append_layer, 
                                   add_layer = TRUE))
     } else {
-      datExportData(sumdat, 
+      datExportData(sumdat, dbconn = out_conn, dbconnopen = FALSE,
               savedata_opts=list(outfolder = outfolder, 
                                   out_fmt = out_fmt, 
                                   out_dsn = out_dsn, 
@@ -470,6 +483,9 @@ datSumCond <- function(cond = NULL,
     }
   }  
 
+  ## Round values
+  sumdat[,(csumvarnm) := lapply(.SD, round, cround), .SDcols=csumvarnm]
+
   if (!returnDT) {     
     sumdat <- data.frame(sumdat)
   }
