@@ -338,6 +338,7 @@ modGBratio <- function(GBpopdat,
   parameters <- FALSE
   returnlst <- list()
   rawdata <- TRUE
+  row.addNA=col.addNA <- FALSE
 
   ## Set global variables
   ONEUNIT=n.total=n.strata=strwt=TOTAL=tdom=estvar.name=
@@ -476,7 +477,6 @@ modGBratio <- function(GBpopdat,
     setkeyv(unitarea, unitvar)
   }
   
-
   ###################################################################################
   ## Check parameters and apply plot and condition filters
   ###################################################################################
@@ -523,7 +523,7 @@ modGBratio <- function(GBpopdat,
   if ("INVYR" %in% names(pltcondf)) {
     invyr <- sort(unique(pltcondf$INVYR))
   }
- 
+
   ###################################################################################
   ### Check row and column data
   ###################################################################################
@@ -565,8 +565,7 @@ modGBratio <- function(GBpopdat,
   rm(rowcolinfo) 
 
   if (rowvar == "TOTAL") rowcol.total <- TRUE
-
-
+  
   #####################################################################################
   ### Get estimation data from tree table
   #####################################################################################
@@ -582,7 +581,7 @@ modGBratio <- function(GBpopdat,
                   adjtree=adjtree, metric=metric, woodland=woodland)
   if (is.null(treedat)) return(NULL)
   tdomdat <- treedat$tdomdat
- 
+
   ## Merge tdomdat with condx
   xchk <- check.matchclass(condx, tdomdat, c(cuniqueid, condid))
   condx <- xchk$tab1
@@ -596,6 +595,7 @@ modGBratio <- function(GBpopdat,
     condf <- xchk$tab2   
     cdomdat <- merge(condx, condf, by=c(cuniqueid, condid))
   }
+  
   estvarn <- treedat$estvarn
   estvarn.name <- treedat$estvarn.name
   estvarn.filter <- treedat$estvarn.filter
@@ -613,14 +613,13 @@ modGBratio <- function(GBpopdat,
     estunitsd <- areaunits
   }  
 
-
   ## Generate a uniquecol for estimation units
   if (!sumunits & colvar == "NONE") {
     uniquecol <- data.table(unitarea[[unitvar]])
     setnames(uniquecol, unitvar)
     uniquecol[[unitvar]] <- factor(uniquecol[[unitvar]])
   }
- 
+
   #####################################################################################
   ### Get titles for output tables
   #####################################################################################
@@ -670,7 +669,7 @@ modGBratio <- function(GBpopdat,
 		by=c(strunitvars, cuniqueid, "TOTAL"), .SDcols=estvard.name]   
     tdomdat <- merge(tdomdat, cdomdattot, by=c(strunitvars, cuniqueid, "TOTAL"))
   }
- 
+
   ## Note: tdomdat is the summed response by condition (not domain)
   if (addtotal) {
     ## Get estimate for total
@@ -716,7 +715,7 @@ modGBratio <- function(GBpopdat,
       } else {
         if (tdomvar == rowvar) {
           tdomdatsum <- transpose2row(tdomdat, uniqueid=c(strunitvars, cuniqueid),
- 			        tvars=tdomvarlstn)
+ 			        tvars=tdomvarlstn, na.rm=FALSE)
           setnames(tdomdatsum, c("variable", "value"), c(rowvar, estvarn.name))
           tdomdatsum <- tdomdatsum[, lapply(.SD, sum, na.rm=TRUE), 
               by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvarn.name]
@@ -739,7 +738,8 @@ modGBratio <- function(GBpopdat,
     } else {
       tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
 		        by=c(strunitvars, cuniqueid, rowvar), .SDcols=c(estvarn.name, estvard.name)]
-    }
+    }	 
+    tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[rowvar]]) & tdomdatsum[[rowvar]] != "NA",] 
     unit_rowest <- GBest.pbar(sumyn = estvarn.name, 
                               sumyd = estvard.name, 
                               ysum = tdomdatsum, 
@@ -752,9 +752,9 @@ modGBratio <- function(GBpopdat,
                               domain = rowvar)
  
     if (colvar != "NONE") {
-      if (!is.null(tdomvar)) {
+       if (!is.null(tdomvar)) {
         if (!is.null(tdomvar2)) {
-          tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+         tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
                   by=c(strunitvars, cuniqueid, colvar), .SDcols=estvarn.name]    
         } else {
           if (tdomvar == colvar) {
@@ -780,7 +780,8 @@ modGBratio <- function(GBpopdat,
       } else {
         tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
                   by=c(strunitvars, cuniqueid, colvar), .SDcols=c(estvarn.name, estvard.name)]
-      }
+      }	  
+      tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[colvar]]) & tdomdatsum[[colvar]] != "NA",] 
       unit_colest <- GBest.pbar(sumyn = estvarn.name, 
                                 sumyd = estvard.name, 
                                 ysum = tdomdatsum, 
@@ -820,7 +821,9 @@ modGBratio <- function(GBpopdat,
         tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
             by=c(strunitvars, cuniqueid, grpvar), .SDcols=c(estvarn.name, estvard.name)]
       }
-      unit_grpest <- GBest.pbar(sumyn = estvarn.name, 
+      tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[rowvar]]) & tdomdatsum[[rowvar]] != "NA",] 
+      tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[colvar]]) & tdomdatsum[[colvar]] != "NA",] 
+	  unit_grpest <- GBest.pbar(sumyn = estvarn.name, 
                                 sumyd = estvard.name, 
                                 ysum = tdomdatsum, 
                                 esttype =esttype, 
@@ -998,7 +1001,7 @@ modGBratio <- function(GBpopdat,
 	      returntitle=returntitle, estnull=estnull, psenull=psenull, raw.keep0=raw.keep0) 
   est2return <- tabs$tabest
   pse2return <- tabs$tabpse
-  
+ 
   if (!is.null(est2return)) {
     returnlst$est <- setDF(est2return)
   }
