@@ -4,7 +4,7 @@
 #' 
 #' Population types \cr \tabular{lll}{ \tab \bold{popType}
 #' \bold{Description}\cr 
-#' \tab ALL \tab Population data, inluding nonsampled plots.\cr 
+#' \tab ALL \tab Population data, including nonsampled plots.\cr 
 #' \tab CURR \tab Population data for area estimates, excluding nonsampled 
 #' plots.\cr 
 #' \tab VOL \tab Population data for area/tree estimates, excluding 
@@ -25,7 +25,7 @@
 #' trees on microplot).\cr 
 #' \tab cond \tab cuniqueid \tab Unique identifier for each plot in cond 
 #' table.\cr 
-#' \tab \tab CONDID \tab Unique identfier of each condition on plot. Set 
+#' \tab \tab CONDID \tab Unique identifier of each condition on plot. Set 
 #' CONDID=1, if only 1 condition per plot.\cr 
 #' \tab \tab CONDPROP_UNADJ \tab Unadjusted proportion of condition on each 
 #' plot. Set CONDPROP_UNADJ=1, if only 1 condition per plot.\cr 
@@ -195,7 +195,7 @@
 #' previous in order.
 #' 
 #' stratcombine:\cr If TRUE and less than 2 plots in any one strata class
-#' within an esimation unit, all strata classes with 2 or less plots are
+#' within an estimation unit, all strata classes with 2 or less plots are
 #' combined. The current method for combining is to group the strata with less
 #' than 2 plots with the strata class following in consecutive order (numeric
 #' or alphabetical), restrained by estimation unit (if unitcombine=FALSE), and
@@ -318,16 +318,17 @@ modWFpop <- function(popType = "VOL",
   }
   
   ## Set user-supplied popFilters values
+  popFilter2 <- popFilters_defaults_list
   if (length(popFilter) > 0) {
     for (i in 1:length(popFilter)) {
       if (names(popFilter)[[i]] %in% names(popFilters_defaults_list)) {
-        assign(names(popFilter)[[i]], popFilter[[i]])
+		popFilter2[[names(popFilter)[[i]]]] <- popFilter[[i]]
       } else {
         stop(paste("Invalid parameter: ", names(popFilter)[[i]]))
       }
     }
   }
-  
+   
   ## Set savedata defaults
   savedata_defaults_list <- formals(savedata_options)[-length(formals(savedata_options))]
   
@@ -470,14 +471,17 @@ modWFpop <- function(popType = "VOL",
   evalTyplst <- c("ALL", "CURR", "VOL", "LULC", "P2VEG", "INV", "DWM", "CHNG", "GRM")
   popType <- pcheck.varchar(var2check=popType, varnm="popType", gui=gui,
 		checklst=evalTyplst, caption="popType", multiple=FALSE, stopifnull=TRUE)
-  if (!is.null(evalid)) {
-    popevalid <- as.character(evalid)
+  popevalid <- as.character(popFilter2$evalid)
+  if (!is.null(popevalid)) {
     substr(popevalid, nchar(popevalid)-1, nchar(popevalid)) <- 
-		FIESTAutils::ref_popType[FIESTAutils::ref_popType$popType %in% popType, "EVAL_TYP_CD"]
-    evalid <- as.character(evalid)
-    substr(evalid, nchar(evalid)-1, nchar(evalid)) <- "01"
+		formatC(FIESTAutils::ref_popType[FIESTAutils::ref_popType$popType %in% popType, "EVAL_TYP_CD"], 
+		width=2, flag="0")
+    #evalid <- as.character(evalid)
+    #substr(evalid, nchar(evalid)-1, nchar(evalid)) <- "01"
   } 
-
+  if (popType %in% c("GROW", "MORT", "REMV")) {
+    popType <- "GRM"
+  }
  
   ###################################################################################
   ## Load data
@@ -625,13 +629,12 @@ modWFpop <- function(popType = "VOL",
   ###################################################################################
   pltcheck <- check.popdataPLT(dsn=dsn, tabs=popTabs, tabIDs=popTabIDs, 
       pltassgn=pltassgn, pltassgnid=pltassgnid, pjoinid=pjoinid, 
-      module="GB", popType=popType, popevalid=popevalid, adj=adj, ACI=ACI, 
-      evalid=evalid, measCur=measCur, measEndyr=measEndyr, 
-      measEndyr.filter=measEndyr.filter, invyrs=invyrs, intensity=intensity,
-      nonsamp.pfilter=nonsamp.pfilter, unitarea=unitarea, areavar=areavar, 
-      unitvar=unitvar, unitvar2=unitvar2, areaunits=areaunits, 
-      unit.action=unit.action, strata=strata, stratalut=stratalut, 
-      strvar=strvar, pivot=pivot, nonresp=nonresp)
+      module="GB", popType=popType, popevalid=popevalid, adj=adj, 
+	  popFilter=popFilter2, nonsamp.pfilter=nonsamp.pfilter, 
+	  unitarea=unitarea, areavar=areavar, unitvar=unitvar, 
+	  unitvar2=unitvar2, areaunits=areaunits, unit.action=unit.action, 
+	  strata=strata, stratalut=stratalut, strvar=strvar, pivot=pivot, 
+	  nonresp=nonresp)
   if (is.null(pltcheck)) return(NULL)
   pltassgnx <- pltcheck$pltassgnx
   pltassgnid <- pltcheck$pltassgnid
