@@ -147,14 +147,12 @@ spPoly2Rast <- function(polyv,
   if (!is.null(rastfn.template)) {
 
     ## verify raster
-    rastfn <- getrastlst.rgdal(rastfn.template)
-
-    ## get format from raster
-    rast_info2 <- suppressWarnings(rgdal::GDALinfo(rastfn))
-    rast.fmt <- attr(rast_info2, "driver")
+    rastfn <- getrastlst(rastfn.template)
 
+    ## get raster info
     rast_info <- rasterInfo(rastfn)
     rast.prj <- rast_info$crs
+    rast.fmt <- rast_info$format
     nbands <- rast_info$nbands
 
     ## Check if projections match
@@ -168,7 +166,7 @@ spPoly2Rast <- function(polyv,
 
     ## Create blank raster from clipped virtual raster
     rast.fmt <- drivers[drivers$DefaultExt == outext, "fmt"]
-    rast <- rasterFromRaster(rastclip, fmt=rast.fmt, dstfile=outfilenm)
+    rast <- gdalraster::rasterFromRaster(rastclip, fmt=rast.fmt, dstfile=outfilenm)
 
     ## Rasterize polygons
     polyrast <- rasterizePolygons(src=polyvx, burn_value=polyv.att, rasterfile=rast)
